@@ -28,7 +28,7 @@
 #' 
 #' \code{nmkbw} is a simple wrapper function for fitting models with the corresponding optimizer. It needs to be exported for \code{lme4}, but should not be called directly by the user.
 #' 
-#' @note code taken from \url{https://github.com/lme4/lme4/blob/master/inst/utils/allFit.R}
+#' @note Very similar to the function of the same name that is part of \pkg{lme4}. The present function will be removed eventually in favor of the \pkg{lme4} function.
 #' 
 #' @return a list of fitted \code{merMod} objects
 #' @seealso slice, slice2D in the bbmle package
@@ -41,11 +41,13 @@
 #' 
 all_fit <- function(m, 
                     meth_tab = cbind(
-                      optimizer=rep(c("bobyqa","Nelder_Mead", "optimx", "nloptwrap", "nmkbw"), 
+                      optimizer=rep(c("bobyqa","Nelder_Mead", "optimx", 
+                                      "nloptwrap", "nmkbw"), 
                                     c( 1, 1, 2, 2, 1)),
-                      method= c("", "", "nlminb","L-BFGS-B","NLOPT_LN_NELDERMEAD", "NLOPT_LN_BOBYQA", "")
+                      method= c("", "", "nlminb","L-BFGS-B",
+                                "NLOPT_LN_NELDERMEAD", "NLOPT_LN_BOBYQA", "")
                       ),
-                    verbose=TRUE,maxfun=1e6, ...)
+                    verbose=TRUE, maxfun=1e6, ...)
 {
   stopifnot(length(dm <- dim(meth_tab)) == 2, dm[1] >= 1, dm[2] >= 2,
             is.character(optimizer <- meth_tab[,"optimizer"]),
@@ -78,7 +80,11 @@ all_fit <- function(m,
       else cat("[ERROR]\n")
     }
   }
-  ##
+  ## reset call slot of refitted objects
+  res <- lapply(res, function(x) {
+    try(x@call[["data"]] <- m@call[["data"]], silent = TRUE)
+    x
+  })
   res
 }
 
