@@ -3,9 +3,16 @@ context("ANOVAs: check that afex_aov return value works")
 
 test_that("split-plot produces an afex_aov object without error", {
   data(obk.long, package = "afex")
-  split_plot1 <- aov_car(value ~ treatment * gender + Error(id/(phase*hour)), data = obk.long, observed = "gender", return = "afex_aov")
-  split_plot2 <- aov_4(value ~ treatment * gender + (phase*hour|id), data = obk.long, observed = "gender", return = "afex_aov")
-  split_plot3 <- aov_ez("id", "value", obk.long, between = c("treatment", "gender"), within = c("phase", "hour"), observed = "gender", return = "afex_aov")
+  split_plot1 <- aov_car(value ~ treatment * gender + Error(id/(phase*hour)), 
+                         data = obk.long, observed = "gender", 
+                         return = "afex_aov")
+  split_plot2 <- aov_4(value ~ treatment * gender + (phase*hour|id), 
+                       data = obk.long, observed = "gender", 
+                       return = "afex_aov")
+  split_plot3 <- aov_ez("id", "value", obk.long, 
+                        between = c("treatment", "gender"), 
+                        within = c("phase", "hour"), observed = "gender", 
+                        return = "afex_aov")
   
   expect_that(split_plot1, is_equivalent_to(split_plot2))
   expect_that(split_plot1, is_equivalent_to(split_plot3))
@@ -13,15 +20,22 @@ test_that("split-plot produces an afex_aov object without error", {
   
   ## is same with numeric factor:
   obk.long$hour <- as.numeric(as.character(obk.long$hour))
-  split_plot4 <- aov_car(value ~ treatment * gender + Error(id/phase*hour), data = obk.long,observed = c("gender"), return = "afex_aov")
+  split_plot4 <- aov_car(value ~ treatment * gender + Error(id/phase*hour), 
+                         data = obk.long,observed = c("gender"), 
+                         return = "afex_aov")
   expect_that(split_plot1, is_equivalent_to(split_plot4))  
 })
 
 test_that("purely-between produces afex_aov objects without error", {
   data(obk.long, package = "afex")
-  out1 <- aov_car(value ~ treatment * gender + Error(id), data = obk.long, observed = "gender", return = "afex_aov", fun_aggregate = mean)
-  out2 <- aov_4(value ~ treatment * gender + (1|id), data = obk.long, observed = "gender", return = "afex_aov", fun_aggregate = mean)
-  out3 <- aov_ez("id", "value", obk.long, between = c("treatment", "gender"), observed = "gender", return = "afex_aov", fun_aggregate = mean)
+  out1 <- aov_car(value ~ treatment * gender + Error(id), data = obk.long, 
+                  observed = "gender", return = "afex_aov", 
+                  fun_aggregate = mean)
+  out2 <- aov_4(value ~ treatment * gender + (1|id), data = obk.long, 
+                observed = "gender", return = "afex_aov", fun_aggregate = mean)
+  out3 <- aov_ez("id", "value", obk.long, 
+                 between = c("treatment", "gender"), observed = "gender", 
+                 return = "afex_aov", fun_aggregate = mean)
   
   expect_that(out1, is_equivalent_to(out2))
   expect_that(out1, is_equivalent_to(out3))
@@ -30,9 +44,12 @@ test_that("purely-between produces afex_aov objects without error", {
 
 test_that("purely-within produces afex_aov objects without error", {
   data(obk.long, package = "afex")
-  out1 <- aov_car(value ~ Error(id/(phase*hour)), data = obk.long, return = "afex_aov")
-  out2 <- aov_4(value ~ 1 +  (phase*hour|id), data = obk.long, return = "afex_aov")
-  out3 <- aov_ez("id", "value", obk.long, within = c("phase", "hour"), return = "afex_aov")
+  out1 <- aov_car(value ~ Error(id/(phase*hour)), data = obk.long, 
+                  return = "afex_aov")
+  out2 <- aov_4(value ~ 1 +  (phase*hour|id), data = obk.long, 
+                return = "afex_aov")
+  out3 <- aov_ez("id", "value", obk.long, within = c("phase", "hour"), 
+                 return = "afex_aov")
   
   expect_that(out1, is_equivalent_to(out2))
   expect_that(out1, is_equivalent_to(out3))
@@ -41,8 +58,10 @@ test_that("purely-within produces afex_aov objects without error", {
 
 test_that("within plus covariate produces afex_aov objects without error", {
   data(obk.long, package = "afex")
-  out1 <- aov_car(value ~ gender + Error(id/(phase*hour)), data = obk.long, return = "afex_aov")
-  out2 <- aov_4(value ~ gender +  (phase*hour|id), data = obk.long, return = "afex_aov")
+  out1 <- aov_car(value ~ gender + Error(id/(phase*hour)), data = obk.long, 
+                  return = "afex_aov")
+  out2 <- aov_4(value ~ gender +  (phase*hour|id), data = obk.long, 
+                return = "afex_aov")
   out3 <- aov_ez("id", "value", obk.long, within = c("phase", "hour"), 
                  covariate = "gender", return = "afex_aov")
   
@@ -54,7 +73,8 @@ test_that("within plus covariate produces afex_aov objects without error", {
 
 test_that("afex_aov object contains the right things", {
   data(obk.long, package = "afex")
-  out1 <- aov_car(value ~ treatment * gender + Error(id/(phase*hour)), data = obk.long, observed = "gender", return = "afex_aov")
+  out1 <- aov_car(value ~ treatment * gender + Error(id/(phase*hour)), 
+                  data = obk.long, observed = "gender", return = "afex_aov")
 
   expect_that(out1[["anova_table"]], is_a(c("anova", "data.frame")))  
   expect_that(out1[["aov"]], is_a(c("aovlist", "listof")))  
@@ -98,4 +118,30 @@ test_that("afex_aov objects works without aov object", {
   expect_message(em4 <- emmeans::emmeans(a1, c("phase", "hour")), "multivariate")
   expect_false(any(as.data.frame(summary(em3))$df == as.data.frame(summary(em4))$df))
   afex_options(op)
-})
\ No newline at end of file
+})
+
+test_that("better error message in case of all data having NAs", {
+  data("stroop")
+  # stroop_e1 <- stroop %>%
+  #   filter(!is.na(acc)) %>% 
+  #   filter(study == "1") %>% 
+  #   droplevels()
+  stroop_e1_na <- stroop[ stroop$study == "1", ]
+  
+  suppressWarnings(expect_error(aov_ez(
+    id = "pno", 
+    dv = "acc", 
+    data = stroop_e1_na,
+    within = c("congruency", "condition")
+  ), "Try adding to ANOVA call: na.rm = TRUE"))
+  
+  expect_is(aov_ez(
+    id = "pno", 
+    dv = "acc", 
+    data = stroop_e1_na,
+    within = c("congruency", "condition"), 
+    na.rm = TRUE, 
+    include_aov = FALSE, 
+    fun_aggregate = mean
+  ), "afex_aov")
+})
