@@ -3,8 +3,10 @@
 context("test_assumptions: check if it works")
 
 data(obk.long, package = "afex")
-between_1 <- aov_car(value ~ treatment + Error(id), data = obk.long)
-between_2 <- aov_car(value ~ treatment*gender + Error(id), data = obk.long)
+between_1 <- aov_car(value ~ treatment + Error(id), data = obk.long, 
+                     fun_aggregate = mean)
+between_2 <- aov_car(value ~ treatment*gender + Error(id), data = obk.long, 
+                     fun_aggregate = mean)
 mixed <- aov_car(value ~ treatment * gender + Error(id/(phase*hour)), data = obk.long)
 within <- aov_car(value ~ 1 + Error(id/(phase*hour)), data = obk.long)
 
